==> ms-users-12.1.1.tgz: package/lib/utils/challenges/email/send.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Sends simple email using mailing microservice
 */
module.exports = exports = function definedSubjectAndSend(props, wait = false) {
  const {
    email,
    type,
    context,
    emailTemplate,
    nodemailer = {}
  } = props;
  const {
    config,
    mailer
  } = this;
  const {
    validation
  } = config;
  const {
    subjects,
    senders,
    email: mailingAccount
  } = validation;

  const mail = _objectSpread({}, nodemailer, {
    subject: subjects[type] || '',
    from: senders[type] || 'noreply <support@example.com>',
    to: email,
    html: emailTemplate
  });

  const mailSent = mailer.send(mailingAccount, mail).return({
    sent: true,
    context
  }).catch(err => ({
    context,
    err,
    sent: false
  }));

  if (wait) {
    return mailSent;
  }

  return {
    queued: true,
    context
  };
};

==> ms-users-14.13.0.tgz: package/lib/utils/challenges/email/send.js <==
"use strict";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Sends simple email using mailing microservice
 */
module.exports = exports = function definedSubjectAndSend(props, wait = false) {
  const {
    email,
    type,
    context,
    emailTemplate,
    nodemailer = {}
  } = props;
  const {
    config,
    mailer
  } = this;
  const {
    validation
  } = config;
  const {
    subjects,
    senders,
    email: mailingAccount
  } = validation;

  const mail = _objectSpread(_objectSpread({}, nodemailer), {}, {
    subject: subjects[type] || '',
    from: senders[type] || 'noreply <support@example.com>',
    to: email,
    html: emailTemplate
  });

  const mailSent = mailer.send(mailingAccount, mail).return({
    sent: true,
    context
  }).catch(err => ({
    context,
    err,
    sent: false
  }));

  if (wait) {
    return mailSent;
  }

  return {
    queued: true,
    context
  };
};
